@@ -2,7 +2,14 @@ use serde::*;
 use std::sync::Arc;
 use wasm_bus::macros::*;
 
-#[wasm_bus(format = "json")]
+#[derive(Debug, Clone, Serialize, Deserialize)]
+pub struct TtyRect
+{
+    pub cols: u32,
+    pub rows: u32,
+}
+
+#[wasm_bus(format = "bincode")]
 pub trait Tty {
     async fn stdin(
         &self,
@@ -17,6 +24,10 @@ pub trait Tty {
     async fn stderr(
         &self,
     ) -> Arc<dyn Stderr>;
+
+    async fn rect(
+        &self,
+    ) -> TtyRect;
 }
 
 #[wasm_bus(format = "bincode")]
@@ -40,4 +51,4 @@ pub trait Stderr {
 pub enum WriteResult {
     Success(usize),
     Failed(String),
-}
+}
\ No newline at end of file
