@@ -1,4 +1,4 @@
-#[cfg(feature = "sys")]
+#[cfg(any(feature = "sys", target_arch = "wasm32"))]
 pub use crate::tty::Tty;
 #[cfg(target_arch = "wasm32")]
 pub use wasm_bus;
